<?php

return [
    'Names' => [
        'af' => 'Afrikaans',
        'af_NA' => 'Afrikaans (Namibia)',
        'af_ZA' => 'Afrikaans (South Africa)',
        'ak' => 'Akan',
        'ak_GH' => 'Akan (Ghana)',
        'am' => 'Amharic',
        'am_ET' => 'Amharic (Ethiopia)',
        'ar' => 'Arabic',
        'ar_001' => 'Arabic (world)',
        'ar_AE' => 'Arabic (United Arab Emirates)',
        'ar_BH' => 'Arabic (Bahrain)',
        'ar_DJ' => 'Arabic (Djibouti)',
        'ar_DZ' => 'Arabic (Algeria)',
        'ar_EG' => 'Arabic (Egypt)',
        'ar_EH' => 'Arabic (Western Sahara)',
        'ar_ER' => 'Arabic (Eritrea)',
        'ar_IL' => 'Arabic (Israel)',
        'ar_IQ' => 'Arabic (Iraq)',
        'ar_JO' => 'Arabic (Jordan)',
        'ar_KM' => 'Arabic (Comoros)',
        'ar_KW' => 'Arabic (Kuwait)',
        'ar_LB' => 'Arabic (Lebanon)',
        'ar_LY' => 'Arabic (Libya)',
        'ar_MA' => 'Arabic (Morocco)',
        'ar_MR' => 'Arabic (Mauritania)',
        'ar_OM' => 'Arabic (Oman)',
        'ar_PS' => 'Arabic (Palestinian Territories)',
        'ar_QA' => 'Arabic (Qatar)',
        'ar_SA' => 'Arabic (Saudi Arabia)',
        'ar_SD' => 'Arabic (Sudan)',
        'ar_SO' => 'Arabic (Somalia)',
        'ar_SS' => 'Arabic (South Sudan)',
        'ar_SY' => 'Arabic (Syria)',
        'ar_TD' => 'Arabic (Chad)',
        'ar_TN' => 'Arabic (Tunisia)',
        'ar_YE' => 'Arabic (Yemen)',
        'as' => 'Assamese',
        'as_IN' => 'Assamese (India)',
        'az' => 'Azerbaijani',
        'az_AZ' => 'Azerbaijani (Azerbaijan)',
        'az_Cyrl' => 'Azerbaijani (Cyrillic)',
        'az_Cyrl_AZ' => 'Azerbaijani (Cyrillic, Azerbaijan)',
        'az_Latn' => 'Azerbaijani (Latin)',
        'az_Latn_AZ' => 'Azerbaijani (Latin, Azerbaijan)',
        'be' => 'Belarusian',
        'be_BY' => 'Belarusian (Belarus)',
        'bg' => 'Bulgarian',
        'bg_BG' => 'Bulgarian (Bulgaria)',
        'bm' => 'Bambara',
        'bm_ML' => 'Bambara (Mali)',
        'bn' => 'Bangla',
        'bn_BD' => 'Bangla (Bangladesh)',
        'bn_IN' => 'Bangla (India)',
        'bo' => 'Tibetan',
        'bo_CN' => 'Tibetan (China)',
        'bo_IN' => 'Tibetan (India)',
        'br' => 'Breton',
        'br_FR' => 'Breton (France)',
        'bs' => 'Bosnian',
        'bs_BA' => 'Bosnian (Bosnia & Herzegovina)',
        'bs_Cyrl' => 'Bosnian (Cyrillic)',
        'bs_Cyrl_BA' => 'Bosnian (Cyrillic, Bosnia & Herzegovina)',
        'bs_Latn' => 'Bosnian (Latin)',
        'bs_Latn_BA' => 'Bosnian (Latin, Bosnia & Herzegovina)',
        'ca' => 'Catalan',
        'ca_AD' => 'Catalan (Andorra)',
        'ca_ES' => 'Catalan (Spain)',
        'ca_FR' => 'Catalan (France)',
        'ca_IT' => 'Catalan (Italy)',
        'ce' => 'Chechen',
        'ce_RU' => 'Chechen (Russia)',
        'cs' => 'Czech',
        'cs_CZ' => 'Czech (Czechia)',
        'cv' => 'Chuvash',
        'cv_RU' => 'Chuvash (Russia)',
        'cy' => 'Welsh',
        'cy_GB' => 'Welsh (United Kingdom)',
        'da' => 'Danish',
        'da_DK' => 'Danish (Denmark)',
        'da_GL' => 'Danish (Greenland)',
        'de' => 'German',
        'de_AT' => 'German (Austria)',
        'de_BE' => 'German (Belgium)',
        'de_CH' => 'German (Switzerland)',
        'de_DE' => 'German (Germany)',
        'de_IT' => 'German (Italy)',
        'de_LI' => 'German (Liechtenstein)',
        'de_LU' => 'German (Luxembourg)',
        'dz' => 'Dzongkha',
        'dz_BT' => 'Dzongkha (Bhutan)',
        'ee' => 'Ewe',
        'ee_GH' => 'Ewe (Ghana)',
        'ee_TG' => 'Ewe (Togo)',
        'el' => 'Greek',
        'el_CY' => 'Greek (Cyprus)',
        'el_GR' => 'Greek (Greece)',
        'en' => 'English',
        'en_001' => 'English (world)',
        'en_150' => 'English (Europe)',
        'en_AE' => 'English (United Arab Emirates)',
        'en_AG' => 'English (Antigua & Barbuda)',
        'en_AI' => 'English (Anguilla)',
        'en_AS' => 'English (American Samoa)',
        'en_AT' => 'English (Austria)',
        'en_AU' => 'English (Australia)',
        'en_BB' => 'English (Barbados)',
        'en_BE' => 'English (Belgium)',
        'en_BI' => 'English (Burundi)',
        'en_BM' => 'English (Bermuda)',
        'en_BS' => 'English (Bahamas)',
        'en_BW' => 'English (Botswana)',
        'en_BZ' => 'English (Belize)',
        'en_CA' => 'English (Canada)',
        'en_CC' => 'English (Cocos [Keeling] Islands)',
        'en_CH' => 'English (Switzerland)',
        'en_CK' => 'English (Cook Islands)',
        'en_CM' => 'English (Cameroon)',
        'en_CX' => 'English (Christmas Island)',
        'en_CY' => 'English (Cyprus)',
        'en_DE' => 'English (Germany)',
        'en_DK' => 'English (Denmark)',
        'en_DM' => 'English (Dominica)',
        'en_ER' => 'English (Eritrea)',
        'en_FI' => 'English (Finland)',
        'en_FJ' => 'English (Fiji)',
        'en_FK' => 'English (Falkland Islands)',
        'en_FM' => 'English (Micronesia)',
        'en_GB' => 'English (United Kingdom)',
        'en_GD' => 'English (Grenada)',
        'en_GG' => 'English (Guernsey)',
        'en_GH' => 'English (Ghana)',
        'en_GI' => 'English (Gibraltar)',
        'en_GM' => 'English (Gambia)',
        'en_GU' => 'English (Guam)',
        'en_GY' => 'English (Guyana)',
        'en_HK' => 'English (Hong Kong SAR China)',
        'en_IE' => 'English (Ireland)',
        'en_IL' => 'English (Israel)',
        'en_IM' => 'English (Isle of Man)',
        'en_IN' => 'English (India)',
        'en_IO' => 'English (British Indian Ocean Territory)',
        'en_JE' => 'English (Jersey)',
        'en_JM' => 'English (Jamaica)',
        'en_KE' => 'English (Kenya)',
        'en_KI' => 'English (Kiribati)',
        'en_KN' => 'English (St. Kitts & Nevis)',
        'en_KY' => 'English (Cayman Islands)',
        'en_LC' => 'English (St. Lucia)',
        'en_LR' => 'English (Liberia)',
        'en_LS' => 'English (Lesotho)',
        'en_MG' => 'English (Madagascar)',
        'en_MH' => 'English (Marshall Islands)',
        'en_MO' => 'English (Macao SAR China)',
        'en_MP' => 'English (Northern Mariana Islands)',
        'en_MS' => 'English (Montserrat)',
        'en_MT' => 'English (Malta)',
        'en_MU' => 'English (Mauritius)',
        'en_MV' => 'English (Maldives)',
        'en_MW' => 'English (Malawi)',
        'en_MY' => 'English (Malaysia)',
        'en_NA' => 'English (Namibia)',
        'en_NF' => 'English (Norfolk Island)',
        'en_NG' => 'English (Nigeria)',
        'en_NL' => 'English (Netherlands)',
        'en_NR' => 'English (Nauru)',
        'en_NU' => 'English (Niue)',
        'en_NZ' => 'English (New Zealand)',
        'en_PG' => 'English (Papua New Guinea)',
        'en_PH' => 'English (Philippines)',
        'en_PK' => 'English (Pakistan)',
        'en_PN' => 'English (Pitcairn Islands)',
        'en_PR' => 'English (Puerto Rico)',
        'en_PW' => 'English (Palau)',
        'en_RW' => 'English (Rwanda)',
        'en_SB' => 'English (Solomon Islands)',
        'en_SC' => 'English (Seychelles)',
        'en_SD' => 'English (Sudan)',
        'en_SE' => 'English (Sweden)',
        'en_SG' => 'English (Singapore)',
        'en_SH' => 'English (St. Helena)',
        'en_SI' => 'English (Slovenia)',
        'en_SL' => 'English (Sierra Leone)',
        'en_SS' => 'English (South Sudan)',
        'en_SX' => 'English (Sint Maarten)',
        'en_SZ' => 'English (Eswatini)',
        'en_TC' => 'English (Turks & Caicos Islands)',
        'en_TK' => 'English (Tokelau)',
        'en_TO' => 'English (Tonga)',
        'en_TT' => 'English (Trinidad & Tobago)',
        'en_TV' => 'English (Tuvalu)',
        'en_TZ' => 'English (Tanzania)',
        'en_UG' => 'English (Uganda)',
        'en_UM' => 'English (U.S. Outlying Islands)',
        'en_US' => 'English (United States)',
        'en_VC' => 'English (St. Vincent & Grenadines)',
        'en_VG' => 'English (British Virgin Islands)',
        'en_VI' => 'English (U.S. Virgin Islands)',
        'en_VU' => 'English (Vanuatu)',
        'en_WS' => 'English (Samoa)',
        'en_ZA' => 'English (South Africa)',
        'en_ZM' => 'English (Zambia)',
        'en_ZW' => 'English (Zimbabwe)',
        'eo' => 'Esperanto',
        'eo_001' => 'Esperanto (world)',
        'es' => 'Spanish',
        'es_419' => 'Spanish (Latin America)',
        'es_AR' => 'Spanish (Argentina)',
        'es_BO' => 'Spanish (Bolivia)',
        'es_BR' => 'Spanish (Brazil)',
        'es_BZ' => 'Spanish (Belize)',
        'es_CL' => 'Spanish (Chile)',
        'es_CO' => 'Spanish (Colombia)',
        'es_CR' => 'Spanish (Costa Rica)',
        'es_CU' => 'Spanish (Cuba)',
        'es_DO' => 'Spanish (Dominican Republic)',
        'es_EC' => 'Spanish (Ecuador)',
        'es_ES' => 'Spanish (Spain)',
        'es_GQ' => 'Spanish (Equatorial Guinea)',
        'es_GT' => 'Spanish (Guatemala)',
        'es_HN' => 'Spanish (Honduras)',
        'es_MX' => 'Spanish (Mexico)',
        'es_NI' => 'Spanish (Nicaragua)',
        'es_PA' => 'Spanish (Panama)',
        'es_PE' => 'Spanish (Peru)',
        'es_PH' => 'Spanish (Philippines)',
        'es_PR' => 'Spanish (Puerto Rico)',
        'es_PY' => 'Spanish (Paraguay)',
        'es_SV' => 'Spanish (El Salvador)',
        'es_US' => 'Spanish (United States)',
        'es_UY' => 'Spanish (Uruguay)',
        'es_VE' => 'Spanish (Venezuela)',
        'et' => 'Estonian',
        'et_EE' => 'Estonian (Estonia)',
        'eu' => 'Basque',
        'eu_ES' => 'Basque (Spain)',
        'fa' => 'Persian',
        'fa_AF' => 'Persian (Afghanistan)',
        'fa_IR' => 'Persian (Iran)',
        'ff' => 'Fula',
        'ff_Adlm' => 'Fula (Adlam)',
        'ff_Adlm_BF' => 'Fula (Adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'Fula (Adlam, Cameroon)',
        'ff_Adlm_GH' => 'Fula (Adlam, Ghana)',
        'ff_Adlm_GM' => 'Fula (Adlam, Gambia)',
        'ff_Adlm_GN' => 'Fula (Adlam, Guinea)',
        'ff_Adlm_GW' => 'Fula (Adlam, Guinea-Bissau)',
        'ff_Adlm_LR' => 'Fula (Adlam, Liberia)',
        'ff_Adlm_MR' => 'Fula (Adlam, Mauritania)',
        'ff_Adlm_NE' => 'Fula (Adlam, Niger)',
        'ff_Adlm_NG' => 'Fula (Adlam, Nigeria)',
        'ff_Adlm_SL' => 'Fula (Adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'Fula (Adlam, Senegal)',
        'ff_CM' => 'Fula (Cameroon)',
        'ff_GN' => 'Fula (Guinea)',
        'ff_Latn' => 'Fula (Latin)',
        'ff_Latn_BF' => 'Fula (Latin, Burkina Faso)',
        'ff_Latn_CM' => 'Fula (Latin, Cameroon)',
        'ff_Latn_GH' => 'Fula (Latin, Ghana)',
        'ff_Latn_GM' => 'Fula (Latin, Gambia)',
        'ff_Latn_GN' => 'Fula (Latin, Guinea)',
        'ff_Latn_GW' => 'Fula (Latin, Guinea-Bissau)',
        'ff_Latn_LR' => 'Fula (Latin, Liberia)',
        'ff_Latn_MR' => 'Fula (Latin, Mauritania)',
        'ff_Latn_NE' => 'Fula (Latin, Niger)',
        'ff_Latn_NG' => 'Fula (Latin, Nigeria)',
        'ff_Latn_SL' => 'Fula (Latin, Sierra Leone)',
        'ff_Latn_SN' => 'Fula (Latin, Senegal)',
        'ff_MR' => 'Fula (Mauritania)',
        'ff_SN' => 'Fula (Senegal)',
        'fi' => 'Finnish',
        'fi_FI' => 'Finnish (Finland)',
        'fo' => 'Faroese',
        'fo_DK' => 'Faroese (Denmark)',
        'fo_FO' => 'Faroese (Faroe Islands)',
        'fr' => 'French',
        'fr_BE' => 'French (Belgium)',
        'fr_BF' => 'French (Burkina Faso)',
        'fr_BI' => 'French (Burundi)',
        'fr_BJ' => 'French (Benin)',
        'fr_BL' => 'French (St. Barthélemy)',
        'fr_CA' => 'French (Canada)',
        'fr_CD' => 'French (Congo - Kinshasa)',
        'fr_CF' => 'French (Central African Republic)',
        'fr_CG' => 'French (Congo - Brazzaville)',
        'fr_CH' => 'French (Switzerland)',
        'fr_CI' => 'French (Côte d’Ivoire)',
        'fr_CM' => 'French (Cameroon)',
        'fr_DJ' => 'French (Djibouti)',
        'fr_DZ' => 'French (Algeria)',
        'fr_FR' => 'French (France)',
        'fr_GA' => 'French (Gabon)',
        'fr_GF' => 'French (French Guiana)',
        'fr_GN' => 'French (Guinea)',
        'fr_GP' => 'French (Guadeloupe)',
        'fr_GQ' => 'French (Equatorial Guinea)',
        'fr_HT' => 'French (Haiti)',
        'fr_KM' => 'French (Comoros)',
        'fr_LU' => 'French (Luxembourg)',
        'fr_MA' => 'French (Morocco)',
        'fr_MC' => 'French (Monaco)',
        'fr_MF' => 'French (St. Martin)',
        'fr_MG' => 'French (Madagascar)',
        'fr_ML' => 'French (Mali)',
        'fr_MQ' => 'French (Martinique)',
        'fr_MR' => 'French (Mauritania)',
        'fr_MU' => 'French (Mauritius)',
        'fr_NC' => 'French (New Caledonia)',
        'fr_NE' => 'French (Niger)',
        'fr_PF' => 'French (French Polynesia)',
        'fr_PM' => 'French (St. Pierre & Miquelon)',
        'fr_RE' => 'French (Réunion)',
        'fr_RW' => 'French (Rwanda)',
        'fr_SC' => 'French (Seychelles)',
        'fr_SN' => 'French (Senegal)',
        'fr_SY' => 'French (Syria)',
        'fr_TD' => 'French (Chad)',
        'fr_TG' => 'French (Togo)',
        'fr_TN' => 'French (Tunisia)',
        'fr_VU' => 'French (Vanuatu)',
        'fr_WF' => 'French (Wallis & Futuna)',
        'fr_YT' => 'French (Mayotte)',
        'fy' => 'Western Frisian',
        'fy_NL' => 'Western Frisian (Netherlands)',
        'ga' => 'Irish',
        'ga_GB' => 'Irish (United Kingdom)',
        'ga_IE' => 'Irish (Ireland)',
        'gd' => 'Scottish Gaelic',
        'gd_GB' => 'Scottish Gaelic (United Kingdom)',
        'gl' => 'Galician',
        'gl_ES' => 'Galician (Spain)',
        'gu' => 'Gujarati',
        'gu_IN' => 'Gujarati (India)',
        'gv' => 'Manx',
        'gv_IM' => 'Manx (Isle of Man)',
        'ha' => 'Hausa',
        'ha_GH' => 'Hausa (Ghana)',
        'ha_NE' => 'Hausa (Niger)',
        'ha_NG' => 'Hausa (Nigeria)',
        'he' => 'Hebrew',
        'he_IL' => 'Hebrew (Israel)',
        'hi' => 'Hindi',
        'hi_IN' => 'Hindi (India)',
        'hi_Latn' => 'Hindi (Latin)',
        'hi_Latn_IN' => 'Hindi (Latin, India)',
        'hr' => 'Croatian',
        'hr_BA' => 'Croatian (Bosnia & Herzegovina)',
        'hr_HR' => 'Croatian (Croatia)',
        'hu' => 'Hungarian',
        'hu_HU' => 'Hungarian (Hungary)',
        'hy' => 'Armenian',
        'hy_AM' => 'Armenian (Armenia)',
        'ia' => 'Interlingua',
        'ia_001' => 'Interlingua (world)',
        'id' => 'Indonesian',
        'id_ID' => 'Indonesian (Indonesia)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (Nigeria)',
        'ii' => 'Sichuan Yi',
        'ii_CN' => 'Sichuan Yi (China)',
        'is' => 'Icelandic',
        'is_IS' => 'Icelandic (Iceland)',
        'it' => 'Italian',
        'it_CH' => 'Italian (Switzerland)',
        'it_IT' => 'Italian (Italy)',
        'it_SM' => 'Italian (San Marino)',
        'it_VA' => 'Italian (Vatican City)',
        'ja' => 'Japanese',
        'ja_JP' => 'Japanese (Japan)',
        'jv' => 'Javanese',
        'jv_ID' => 'Javanese (Indonesia)',
        'ka' => 'Georgian',
        'ka_GE' => 'Georgian (Georgia)',
        'ki' => 'Kikuyu',
        'ki_KE' => 'Kikuyu (Kenya)',
        'kk' => 'Kazakh',
        'kk_KZ' => 'Kazakh (Kazakhstan)',
        'kl' => 'Kalaallisut',
        'kl_GL' => 'Kalaallisut (Greenland)',
        'km' => 'Khmer',
        'km_KH' => 'Khmer (Cambodia)',
        'kn' => 'Kannada',
        'kn_IN' => 'Kannada (India)',
        'ko' => 'Korean',
        'ko_KP' => 'Korean (North Korea)',
        'ko_KR' => 'Korean (South Korea)',
        'ks' => 'Kashmiri',
        'ks_Arab' => 'Kashmiri (Arabic)',
        'ks_Arab_IN' => 'Kashmiri (Arabic, India)',
        'ks_Deva' => 'Kashmiri (Devanagari)',
        'ks_Deva_IN' => 'Kashmiri (Devanagari, India)',
        'ks_IN' => 'Kashmiri (India)',
        'ku' => 'Kurdish',
        'ku_TR' => 'Kurdish (Türkiye)',
        'kw' => 'Cornish',
        'kw_GB' => 'Cornish (United Kingdom)',
        'ky' => 'Kyrgyz',
        'ky_KG' => 'Kyrgyz (Kyrgyzstan)',
        'lb' => 'Luxembourgish',
        'lb_LU' => 'Luxembourgish (Luxembourg)',
        'lg' => 'Ganda',
        'lg_UG' => 'Ganda (Uganda)',
        'ln' => 'Lingala',
        'ln_AO' => 'Lingala (Angola)',
        'ln_CD' => 'Lingala (Congo - Kinshasa)',
        'ln_CF' => 'Lingala (Central African Republic)',
        'ln_CG' => 'Lingala (Congo - Brazzaville)',
        'lo' => 'Lao',
        'lo_LA' => 'Lao (Laos)',
        'lt' => 'Lithuanian',
        'lt_LT' => 'Lithuanian (Lithuania)',
        'lu' => 'Luba-Katanga',
        'lu_CD' => 'Luba-Katanga (Congo - Kinshasa)',
        'lv' => 'Latvian',
        'lv_LV' => 'Latvian (Latvia)',
        'mg' => 'Malagasy',
        'mg_MG' => 'Malagasy (Madagascar)',
        'mi' => 'Māori',
        'mi_NZ' => 'Māori (New Zealand)',
        'mk' => 'Macedonian',
        'mk_MK' => 'Macedonian (North Macedonia)',
        'ml' => 'Malayalam',
        'ml_IN' => 'Malayalam (India)',
        'mn' => 'Mongolian',
        'mn_MN' => 'Mongolian (Mongolia)',
        'mr' => 'Marathi',
        'mr_IN' => 'Marathi (India)',
        'ms' => 'Malay',
        'ms_BN' => 'Malay (Brunei)',
        'ms_ID' => 'Malay (Indonesia)',
        'ms_MY' => 'Malay (Malaysia)',
        'ms_SG' => 'Malay (Singapore)',
        'mt' => 'Maltese',
        'mt_MT' => 'Maltese (Malta)',
        'my' => 'Burmese',
        'my_MM' => 'Burmese (Myanmar [Burma])',
        'nb' => 'Norwegian Bokmål',
        'nb_NO' => 'Norwegian Bokmål (Norway)',
        'nb_SJ' => 'Norwegian Bokmål (Svalbard & Jan Mayen)',
        'nd' => 'North Ndebele',
        'nd_ZW' => 'North Ndebele (Zimbabwe)',
        'ne' => 'Nepali',
        'ne_IN' => 'Nepali (India)',
        'ne_NP' => 'Nepali (Nepal)',
        'nl' => 'Dutch',
        'nl_AW' => 'Dutch (Aruba)',
        'nl_BE' => 'Dutch (Belgium)',
        'nl_BQ' => 'Dutch (Caribbean Netherlands)',
        'nl_CW' => 'Dutch (Curaçao)',
        'nl_NL' => 'Dutch (Netherlands)',
        'nl_SR' => 'Dutch (Suriname)',
        'nl_SX' => 'Dutch (Sint Maarten)',
        'nn' => 'Norwegian Nynorsk',
        'nn_NO' => 'Norwegian Nynorsk (Norway)',
        'no' => 'Norwegian',
        'no_NO' => 'Norwegian (Norway)',
        'om' => 'Oromo',
        'om_ET' => 'Oromo (Ethiopia)',
        'om_KE' => 'Oromo (Kenya)',
        'or' => 'Odia',
        'or_IN' => 'Odia (India)',
        'os' => 'Ossetic',
        'os_GE' => 'Ossetic (Georgia)',
        'os_RU' => 'Ossetic (Russia)',
        'pa' => 'Punjabi',
        'pa_Arab' => 'Punjabi (Arabic)',
        'pa_Arab_PK' => 'Punjabi (Arabic, Pakistan)',
        'pa_Guru' => 'Punjabi (Gurmukhi)',
        'pa_Guru_IN' => 'Punjabi (Gurmukhi, India)',
        'pa_IN' => 'Punjabi (India)',
        'pa_PK' => 'Punjabi (Pakistan)',
        'pl' => 'Polish',
        'pl_PL' => 'Polish (Poland)',
        'ps' => 'Pashto',
        'ps_AF' => 'Pashto (Afghanistan)',
        'ps_PK' => 'Pashto (Pakistan)',
        'pt' => 'Portuguese',
        'pt_AO' => 'Portuguese (Angola)',
        'pt_BR' => 'Portuguese (Brazil)',
        'pt_CH' => 'Portuguese (Switzerland)',
        'pt_CV' => 'Portuguese (Cape Verde)',
        'pt_GQ' => 'Portuguese (Equatorial Guinea)',
        'pt_GW' => 'Portuguese (Guinea-Bissau)',
        'pt_LU' => 'Portuguese (Luxembourg)',
        'pt_MO' => 'Portuguese (Macao SAR China)',
        'pt_MZ' => 'Portuguese (Mozambique)',
        'pt_PT' => 'Portuguese (Portugal)',
        'pt_ST' => 'Portuguese (São Tomé & Príncipe)',
        'pt_TL' => 'Portuguese (Timor-Leste)',
        'qu' => 'Quechua',
        'qu_BO' => 'Quechua (Bolivia)',
        'qu_EC' => 'Quechua (Ecuador)',
        'qu_PE' => 'Quechua (Peru)',
        'rm' => 'Romansh',
        'rm_CH' => 'Romansh (Switzerland)',
        'rn' => 'Rundi',
        'rn_BI' => 'Rundi (Burundi)',
        'ro' => 'Romanian',
        'ro_MD' => 'Romanian (Moldova)',
        'ro_RO' => 'Romanian (Romania)',
        'ru' => 'Russian',
        'ru_BY' => 'Russian (Belarus)',
        'ru_KG' => 'Russian (Kyrgyzstan)',
        'ru_KZ' => 'Russian (Kazakhstan)',
        'ru_MD' => 'Russian (Moldova)',
        'ru_RU' => 'Russian (Russia)',
        'ru_UA' => 'Russian (Ukraine)',
        'rw' => 'Kinyarwanda',
        'rw_RW' => 'Kinyarwanda (Rwanda)',
        'sa' => 'Sanskrit',
        'sa_IN' => 'Sanskrit (India)',
        'sc' => 'Sardinian',
        'sc_IT' => 'Sardinian (Italy)',
        'sd' => 'Sindhi',
        'sd_Arab' => 'Sindhi (Arabic)',
        'sd_Arab_PK' => 'Sindhi (Arabic, Pakistan)',
        'sd_Deva' => 'Sindhi (Devanagari)',
        'sd_Deva_IN' => 'Sindhi (Devanagari, India)',
        'sd_IN' => 'Sindhi (India)',
        'sd_PK' => 'Sindhi (Pakistan)',
        'se' => 'Northern Sami',
        'se_FI' => 'Northern Sami (Finland)',
        'se_NO' => 'Northern Sami (Norway)',
        'se_SE' => 'Northern Sami (Sweden)',
        'sg' => 'Sango',
        'sg_CF' => 'Sango (Central African Republic)',
        'sh' => 'Serbo-Croatian',
        'sh_BA' => 'Serbo-Croatian (Bosnia & Herzegovina)',
        'si' => 'Sinhala',
        'si_LK' => 'Sinhala (Sri Lanka)',
        'sk' => 'Slovak',
        'sk_SK' => 'Slovak (Slovakia)',
        'sl' => 'Slovenian',
        'sl_SI' => 'Slovenian (Slovenia)',
        'sn' => 'Shona',
        'sn_ZW' => 'Shona (Zimbabwe)',
        'so' => 'Somali',
        'so_DJ' => 'Somali (Djibouti)',
        'so_ET' => 'Somali (Ethiopia)',
        'so_KE' => 'Somali (Kenya)',
        'so_SO' => 'Somali (Somalia)',
        'sq' => 'Albanian',
        'sq_AL' => 'Albanian (Albania)',
        'sq_MK' => 'Albanian (North Macedonia)',
        'sr' => 'Serbian',
        'sr_BA' => 'Serbian (Bosnia & Herzegovina)',
        'sr_Cyrl' => 'Serbian (Cyrillic)',
        'sr_Cyrl_BA' => 'Serbian (Cyrillic, Bosnia & Herzegovina)',
        'sr_Cyrl_ME' => 'Serbian (Cyrillic, Montenegro)',
        'sr_Cyrl_RS' => 'Serbian (Cyrillic, Serbia)',
        'sr_Latn' => 'Serbian (Latin)',
        'sr_Latn_BA' => 'Serbian (Latin, Bosnia & Herzegovina)',
        'sr_Latn_ME' => 'Serbian (Latin, Montenegro)',
        'sr_Latn_RS' => 'Serbian (Latin, Serbia)',
        'sr_ME' => 'Serbian (Montenegro)',
        'sr_RS' => 'Serbian (Serbia)',
        'su' => 'Sundanese',
        'su_ID' => 'Sundanese (Indonesia)',
        'su_Latn' => 'Sundanese (Latin)',
        'su_Latn_ID' => 'Sundanese (Latin, Indonesia)',
        'sv' => 'Swedish',
        'sv_AX' => 'Swedish (Åland Islands)',
        'sv_FI' => 'Swedish (Finland)',
        'sv_SE' => 'Swedish (Sweden)',
        'sw' => 'Swahili',
        'sw_CD' => 'Swahili (Congo - Kinshasa)',
        'sw_KE' => 'Swahili (Kenya)',
        'sw_TZ' => 'Swahili (Tanzania)',
        'sw_UG' => 'Swahili (Uganda)',
        'ta' => 'Tamil',
        'ta_IN' => 'Tamil (India)',
        'ta_LK' => 'Tamil (Sri Lanka)',
        'ta_MY' => 'Tamil (Malaysia)',
        'ta_SG' => 'Tamil (Singapore)',
        'te' => 'Telugu',
        'te_IN' => 'Telugu (India)',
        'tg' => 'Tajik',
        'tg_TJ' => 'Tajik (Tajikistan)',
        'th' => 'Thai',
        'th_TH' => 'Thai (Thailand)',
        'ti' => 'Tigrinya',
        'ti_ER' => 'Tigrinya (Eritrea)',
        'ti_ET' => 'Tigrinya (Ethiopia)',
        'tk' => 'Turkmen',
        'tk_TM' => 'Turkmen (Turkmenistan)',
        'tl' => 'Tagalog',
        'tl_PH' => 'Tagalog (Philippines)',
        'to' => 'Tongan',
        'to_TO' => 'Tongan (Tonga)',
        'tr' => 'Turkish',
        'tr_CY' => 'Turkish (Cyprus)',
        'tr_TR' => 'Turkish (Türkiye)',
        'tt' => 'Tatar',
        'tt_RU' => 'Tatar (Russia)',
        'ug' => 'Uyghur',
        'ug_CN' => 'Uyghur (China)',
        'uk' => 'Ukrainian',
        'uk_UA' => 'Ukrainian (Ukraine)',
        'ur' => 'Urdu',
        'ur_IN' => 'Urdu (India)',
        'ur_PK' => 'Urdu (Pakistan)',
        'uz' => 'Uzbek',
        'uz_AF' => 'Uzbek (Afghanistan)',
        'uz_Arab' => 'Uzbek (Arabic)',
        'uz_Arab_AF' => 'Uzbek (Arabic, Afghanistan)',
        'uz_Cyrl' => 'Uzbek (Cyrillic)',
        'uz_Cyrl_UZ' => 'Uzbek (Cyrillic, Uzbekistan)',
        'uz_Latn' => 'Uzbek (Latin)',
        'uz_Latn_UZ' => 'Uzbek (Latin, Uzbekistan)',
        'uz_UZ' => 'Uzbek (Uzbekistan)',
        'vi' => 'Vietnamese',
        'vi_VN' => 'Vietnamese (Vietnam)',
        'wo' => 'Wolof',
        'wo_SN' => 'Wolof (Senegal)',
        'xh' => 'Xhosa',
        'xh_ZA' => 'Xhosa (South Africa)',
        'yi' => 'Yiddish',
        'yi_001' => 'Yiddish (world)',
        'yo' => 'Yoruba',
        'yo_BJ' => 'Yoruba (Benin)',
        'yo_NG' => 'Yoruba (Nigeria)',
        'zh' => 'Chinese',
        'zh_CN' => 'Chinese (China)',
        'zh_HK' => 'Chinese (Hong Kong SAR China)',
        'zh_Hans' => 'Chinese (Simplified)',
        'zh_Hans_CN' => 'Chinese (Simplified, China)',
        'zh_Hans_HK' => 'Chinese (Simplified, Hong Kong SAR China)',
        'zh_Hans_MO' => 'Chinese (Simplified, Macao SAR China)',
        'zh_Hans_SG' => 'Chinese (Simplified, Singapore)',
        'zh_Hant' => 'Chinese (Traditional)',
        'zh_Hant_HK' => 'Chinese (Traditional, Hong Kong SAR China)',
        'zh_Hant_MO' => 'Chinese (Traditional, Macao SAR China)',
        'zh_Hant_TW' => 'Chinese (Traditional, Taiwan)',
        'zh_MO' => 'Chinese (Macao SAR China)',
        'zh_SG' => 'Chinese (Singapore)',
        'zh_TW' => 'Chinese (Taiwan)',
        'zu' => 'Zulu',
        'zu_ZA' => 'Zulu (South Africa)',
    ],
];
